ThemePalette class

Constructors

ThemePalette({required String ident, required Color color, ThemeData? data, WidgetBuilder? onDisplay})

Properties

color Color
final
data ThemeData?
final
hashCode int
The hash code for this object.
no setterinherited
ident String
final
onDisplay WidgetBuilder?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

themeList List<ThemePalette>
getter/setter pair

Static Methods

loadTheme() bool
after HareApp.prepare()
showPalette(BuildContext context) → void

Constants

T_DARK → const String
T_LIGHT → const String
T_SYS → const String