HareLayout class
- Inheritance
- Available extensions
Constructors
-
HareLayout({Key? key, required List<
Widget> children, double itemWidth = 240, LastRow lastRow = LastRow.lastItem, EdgeInsets padding = const EdgeInsets.all(0), double spaceX = 8, double spaceY = 8}) -
const
Properties
-
children
→ List<
Widget> -
The widgets below this widget in the tree.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- itemWidth → double
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- lastRow → LastRow
-
final
- padding → EdgeInsets
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spaceX → double
-
final
- spaceY → double
-
final
- withRouterData → RouterDataWidget
-
Available on Widget, provided by the WidgetRouterDataEx extension
no setter
Methods
-
align(
Alignment alignment, {double? widthFactor, double? heightFactor}) → Align -
Available on Widget, provided by the WidgetChainExt extension
-
alignCenter(
{double? widthFactor, double? heightFactor}) → Align -
Available on Widget, provided by the WidgetChainExt extension
-
animatedBuilder(
{Key? key, required Listenable animation, required Widget builder(BuildContext, Widget?)}) → AnimatedBuilder -
Available on Widget, provided by the WidgetChainExt extension
-
aspectRatio(
double ratio) → AspectRatio -
Available on Widget, provided by the WidgetChainExt extension
-
bothScrollBar(
{ScrollController? hor, ScrollController? ver, int horDepth = 0, int verDepth = 0, ScrollPhysics? physics}) → Widget -
Available on Widget, provided by the WidgetScrollExt extension
-
boxDecorated(
{Color? color, BoxBorder? border, double? radiusAll, BoxShadow? shadow, BorderRadiusGeometry? borderRadius, List< BoxShadow> ? boxShadow, DecorationImage? image, Gradient? gradient, BlendMode? backgroundBlendMode, BoxShape shape = BoxShape.rectangle}) → DecoratedBox -
Available on Widget, provided by the WidgetChainExt extension
-
carded(
{Color? color, Color? shadowColor, double? elevation, ShapeBorder? shape, bool semanticContainer = true, bool borderOnForeground = true, EdgeInsetsGeometry? margin, Clip? clipBehavior}) → Card -
Available on Widget, provided by the WidgetChainExt extension
-
centered(
{double? widthFactor, double? heightFactor}) → Widget -
Available on Widget, provided by the WidgetChainExt extension
-
clipRect(
{Clip clipBehavior = Clip.hardEdge}) → ClipRect -
Available on Widget, provided by the WidgetChainExt extension
-
clipRoundRect(
[double radius = 4]) → ClipRRect -
Available on Widget, provided by the WidgetChainExt extension
-
coloredBox(
Color color) → ColoredBox -
Available on Widget, provided by the WidgetChainExt extension
-
constrainedBox(
{double minWidth = 0, double maxWidth = double.infinity, double minHeight = 0, double maxHeight = double.infinity}) → ConstrainedBox -
Available on Widget, provided by the WidgetChainExt extension
-
container(
{Key? key, EdgeInsets? padding, EdgeInsets? margin, Alignment? alignment, Color? color, double? radius, BoxConstraints? constraints, Decoration? decoration, double? width, double? height, Decoration? foregroundDecoration, Matrix4? transform, AlignmentGeometry? transformAlignment, Clip clipBehavior = Clip.none}) → Container -
Available on Widget, provided by the WidgetChainExt extension
-
contextActions(
{required List< XAction> actions, VoidCallback? onCanceled, bool enable = true, bool popOnTap = false, bool popOnLongPress = true, bool popOnRightClick = true, Offset offset = Offset.zero, Color? hoverColor, double? borderRadius = 3}) → PopMenu<XAction> -
Available on Widget, provided by the WidgetPopExt extension
-
contextMenu<
T> ({List< LabelValue< ? values, List<T> >PopupMenuEntry< ? items, PopupMenuItemBuilder<T> >T> ? builder, FuncP<T> ? onSelected, VoidCallback? onCanceled, T? initialValue, bool enable = true, bool popOnTap = false, bool popOnLongPress = true, bool popOnRightClick = true, Offset offset = Offset.zero, Color? hoverColor, double? borderRadius = 3}) → PopMenu<T> -
Available on Widget, provided by the WidgetPopExt extension
-
createElement(
) → MultiChildRenderObjectElement -
RenderObjectWidgets always inflate to a RenderObjectElement subclass.
inherited
-
createRenderObject(
BuildContext context) → HareRenderBox -
Creates an instance of the RenderObject class that this
RenderObjectWidget represents, using the configuration described by this
RenderObjectWidget.
override
-
dataWidget<
D> (D data) → DataWidget< D> -
Available on Widget, provided by the WidgetChainExt extension
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
decoratedBox(
Decoration decoration) → DecoratedBox -
Available on Widget, provided by the WidgetChainExt extension
-
defaultTextStyle(
{required TextStyle style, TextAlign? textAlign, bool softWrap = true, TextOverflow overflow = TextOverflow.clip, int? maxLines, TextWidthBasis textWidthBasis = TextWidthBasis.parent, TextHeightBehavior? textHeightBehavior}) → Widget -
Available on Widget, provided by the WidgetChainExt extension
-
didUnmountRenderObject(
covariant RenderObject renderObject) → void -
This method is called when a RenderObject that was previously
associated with this widget is removed from the render tree.
The provided RenderObject will be of the same type as the one created by
this widget's createRenderObject method.
inherited
-
expanded(
[int flex = 1]) → Expanded -
Available on Widget, provided by the WidgetChainExt extension
-
fadeTransition(
{Key? key, required Animation< double> opacity, bool alwaysIncludeSemantics = false}) → FadeTransition -
Available on Widget, provided by the WidgetChainExt extension
-
fillOrScrollX(
{required double width, ScrollController? controller}) → Widget -
Available on Widget, provided by the WidgetScrollExt extension
-
flexible(
{int flex = 1}) → Flexible -
Available on Widget, provided by the WidgetChainExt extension
-
flip(
{bool flipX = false, bool flipY = false, Offset? origin, FilterQuality? filterQuality}) → Transform -
Available on Widget, provided by the WidgetChainExt extension
-
gesture(
{GestureTapCallback? onTap, GestureTapCallback? onDoubleTap, GestureTapCallback? onSecondaryTap, GestureTapCallback? onRightTap, GestureLongPressCallback? onLongPress, GestureDragUpdateCallback? onPanUpdate}) → GestureDetector -
Available on Widget, provided by the WidgetChainExt extension
-
horizontalScroll(
{ScrollController? controller, ScrollPhysics? physics}) → SingleChildScrollView -
Available on Widget, provided by the WidgetScrollExt extension
-
horScrollBar(
{ScrollController? controller, int depth = 0, ScrollPhysics? physics}) → Widget -
Available on Widget, provided by the WidgetScrollExt extension
-
inkWell(
{Key? key, VoidCallback? onTap, VoidCallback? onDoubleTap, void onSecondaryTap()?, void onLongPress()?, void onHover(bool)?, void onTapDown(TapDownDetails)?, void onTapUp(TapUpDetails)?, void onTapCancel()?, void onSecondaryTapUp(TapUpDetails)?, void onSecondaryTapDown(TapDownDetails)?, void onSecondaryTapCancel()?, void onHighlightChanged(bool)?, void onFocusChange(bool)?, Color? hoverColor, Color? focusColor, Color? highlightColor, Color? splashColor, WidgetStateProperty< Color?> ? overlayColor, InteractiveInkFeatureFactory? splashFactory, BorderRadius? borderRadius, ShapeBorder? customBorder, double? radius, MouseCursor? mouseCursor, bool? enableFeedback = true, bool excludeFromSemantics = false, FocusNode? focusNode, bool canRequestFocus = true, bool autofocus = false, WidgetStatesController? statesController, Duration? hoverDuration}) → InkWell -
Available on Widget, provided by the WidgetChainExt extension
-
intrinsicHeight(
) → IntrinsicHeight -
Available on Widget, provided by the WidgetChainExt extension
-
intrinsicWidth(
{double? stepWidth, double? stepHeight}) → IntrinsicWidth -
Available on Widget, provided by the WidgetChainExt extension
-
labeled(
Widget label) → Widget -
Available on Widget, provided by the WidgetChainExt extension
-
labelText(
String label) → Widget -
Available on Widget, provided by the WidgetChainExt extension
-
limited(
{double? maxWidth, double? maxHeight}) → LimitedBox -
Available on Widget, provided by the WidgetChainExt extension
-
material(
{MaterialType type = MaterialType.canvas, double elevation = 0.0, Color? color, Color? shadowColor, Color? surfaceTintColor, TextStyle? textStyle, BorderRadiusGeometry? borderRadius, ShapeBorder? shape, bool borderOnForeground = true, Clip clipBehavior = Clip.none}) → Material -
Available on Widget, provided by the WidgetChainExt extension
-
matrixTransition(
{Key? key, required Animation< double> animation, required Matrix4 onTransform(double), Alignment alignment = Alignment.center, FilterQuality? filterQuality}) → MatrixTransition -
Available on Widget, provided by the WidgetChainExt extension
-
noSelection(
) → SelectionContainer -
Available on Widget, provided by the WidgetChainExt extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
opacity(
double opacity, [bool alwaysIncludeSemantics = false]) → Widget -
Available on Widget, provided by the WidgetChainExt extension
-
padded(
EdgeInsets? insets) → Widget -
Available on Widget, provided by the WidgetChainExt extension
-
paddings(
{double? left, double? top, double? right, double? bottom, double? hor, double? ver, double? all}) → Padding -
Available on Widget, provided by the WidgetChainExt extension
-
physicalModel(
{required Color color, double? radius = 3, double elevation = 3, Color shadowColor = Colors.black, BorderRadius? borderRadius}) → Widget -
Available on Widget, provided by the WidgetChainExt extension
-
popActions(
{List< XAction> ? items, List<XAction> builder(BuildContext)?}) → Widget -
Available on Widget, provided by the WidgetPopButtonExt extension
-
popLabelValues<
T> ({List< LabelValue< ? items, List<T> >LabelValue< builder(BuildContext)?, Widget display(LabelValue<T> >T> )?, required void callback(LabelValue<T> ), LabelValue<T> ? initialValue, T? value}) → Widget -
Available on Widget, provided by the WidgetPopButtonExt extension
-
popPairs<
T> ({required List< LabelValue< items, Widget display(LabelValue<T> >T> )?, required void callback(LabelValue<T> ), T? value}) → Widget -
Available on Widget, provided by the WidgetPopButtonExt extension
-
popValues<
T> ({List< T> ? items, List<T> builder(BuildContext)?, Widget display(T)?, required void callback(T), T? initialValue}) → Widget -
Available on Widget, provided by the WidgetPopButtonExt extension
-
positioned(
{double? left, double? top, double? right, double? bottom, double? width, double? height}) → Positioned -
Available on Widget, provided by the WidgetChainExt extension
-
positionedFill(
{double? left = 0, double? top = 0, double? right = 0, double? bottom = 0}) → Positioned -
Available on Widget, provided by the WidgetChainExt extension
-
pullRefresh(
RefreshCallback callback) → Widget -
Available on Widget, provided by the WidgetChainExt extension
-
refreshIndicator(
{required Future< void> onRefresh()}) → Widget -
Available on Widget, provided by the WidgetChainExt extension
-
rotatedBox(
int quarterTurns) → RotatedBox -
Available on Widget, provided by the WidgetChainExt extension
-
rotationTransition(
{Key? key, required Animation< double> turns, Alignment alignment = Alignment.center, FilterQuality? filterQuality}) → RotationTransition -
Available on Widget, provided by the WidgetChainExt extension
-
roundRect(
{double radius = 4, Color? borderColor, double bordeWidth = 1.0, Color? fillColor, BoxShadow? shadow}) → DecoratedBox -
Available on Widget, provided by the WidgetChainExt extension
-
safeArea(
{bool left = true, bool top = true, bool right = true, bool bottom = true, EdgeInsets minimum = EdgeInsets.zero, bool maintainBottomViewPadding = false}) → Widget -
Available on Widget, provided by the WidgetChainExt extension
-
scaleTransition(
{Key? key, required Animation< double> scale, Alignment alignment = Alignment.center, FilterQuality? filterQuality}) → ScaleTransition -
Available on Widget, provided by the WidgetChainExt extension
-
scrollBarView(
{required Axis axis, ScrollController? controller, int depth = 0, ScrollPhysics? physics}) → Widget -
Available on Widget, provided by the WidgetScrollExt extension
-
scrollView(
{Axis direction = Axis.vertical, EdgeInsets? padding, ScrollController? controller, ScrollPhysics? physics}) → SingleChildScrollView -
Available on Widget, provided by the WidgetScrollExt extension
-
selectionArea(
) → SelectionArea -
Available on Widget, provided by the WidgetChainExt extension
-
shapeDecorated(
{required ShapeBorder shape, Color? color, DecorationImage? image, Gradient? gradient, List< BoxShadow> ? shadows}) → DecoratedBox -
Available on Widget, provided by the WidgetChainExt extension
-
shapeLinear(
{Color? fillColor, Color? borderColor, BorderSide? side, LinearBorderEdge? start, LinearBorderEdge? end, LinearBorderEdge? top, LinearBorderEdge? bottom}) → Widget -
Available on Widget, provided by the WidgetChainExt extension
-
shapeRounded(
{Color? fillColor, Color? borderColor, BorderSide? side, double radius = 4}) → Widget -
Available on Widget, provided by the WidgetChainExt extension
-
shapeStadium(
{Color? fillColor, Color? borderColor, BorderSide? side}) → Widget -
Available on Widget, provided by the WidgetChainExt extension
-
sizedBox(
{double? width, double? height, double? all}) → SizedBox -
Available on Widget, provided by the WidgetChainExt extension
-
sizeTransition(
{Key? key, Axis axis = Axis.vertical, required Animation< double> sizeFactor, double axisAlignment = 0.0, double? fixedCrossAxisSizeFactor}) → SizeTransition -
Available on Widget, provided by the WidgetChainExt extension
-
slideTransition(
{Key? key, required Animation< Offset> position, bool transformHitTests = true, TextDirection? textDirection}) → SlideTransition -
Available on Widget, provided by the WidgetChainExt extension
-
stack(
{AlignmentGeometry alignment = AlignmentDirectional.topStart, TextDirection? textDirection, StackFit fit = StackFit.loose, Clip clipBehavior = Clip.hardEdge}) → Stack -
Available on Widget, provided by the WidgetChainExt extension
-
stadiumElevatedButton(
VoidCallback? onPressed) → Widget -
Available on Widget, provided by the WidgetButtonsExt extension
-
stadiumOutlinedButton(
VoidCallback? onPressed) → Widget -
Available on Widget, provided by the WidgetButtonsExt extension
-
tab(
{double? height}) → Tab -
Available on Widget, provided by the WidgetChainExt extension
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
underLine(
) → DecoratedBox -
Available on Widget, provided by the WidgetChainExt extension
-
updateRenderObject(
BuildContext context, covariant RenderObject renderObject) → void -
Copies the configuration described by this RenderObjectWidget to the
given RenderObject, which will be of the same type as returned by this
object's createRenderObject.
inherited
-
verScrollBar(
{ScrollController? controller, int depth = 0, ScrollPhysics? physics}) → Widget -
Available on Widget, provided by the WidgetScrollExt extension
-
verticalScroll(
{ScrollController? controller, ScrollPhysics? physics}) → SingleChildScrollView -
Available on Widget, provided by the WidgetScrollExt extension
-
wellAction(
{Alignment? alignment = Alignment.center, Color? fillColor, double fillOpacity = 0.4, Color? hoverColor, double radius = 4, VoidCallback? onTap}) → Widget -
Available on Widget, provided by the WidgetChainExt extension
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited