LengthValidator class

Constructors

LengthValidator({required int minLength, required int maxLength, bool allowEmpty = false, bool trim = false, String? message})

Properties

allowEmpty bool
final
hashCode int
The hash code for this object.
no setterinherited
maxLength int
final
message String
getter/setter pair
minLength int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trim bool
final

Methods

call(String? text) String?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited