LocalStore class

Properties

hashCode int
The hash code for this object.
no setterinherited
keySet Set<String>
no setter
prefer → SharedPreferences
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

exists(String key) bool
getBool(Object key) bool?
getDouble(Object key) double?
getInt(Object key) int?
getObject(String key) Object?
getString(Object key) String?
getStringList(Object key) List<String>?
getValue<T>(Object key) → T?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setBool(Object key, bool? value) → void
setDouble(Object key, double? value) → void
setInt(Object key, int? value) → void
setObject(String key, Object? value) Future<bool>
setString(Object key, String? value) → void
setStringList(Object key, List<String>? value) → void
setValue(Object key, Object? value) Future<bool>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](Object key) String?
operator []=(Object key, String? value) → void

Static Properties

inst LocalStore
no setter

Static Methods

prepare() Future<bool>