Toast class

Constructors

Toast()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

defaultAlignment Alignment
getter/setter pair
noIcon bool
getter/setter pair

Static Methods

error(String? title, {int durationMS = 5000, String titleMiss = "操作失败"}) → void
info(String title, {int durationMS = 3000, Color? fillColor, Color? color}) → void
show(ToastItem item) → void
success(String title, {int durationMS = 2000}) → void
warn(String title, {int durationMS = 4000}) → void