ValidatorList class

Constructors

ValidatorList([List<TextValidator>? vs])

Properties

hashCode int
The hash code for this object.
no setterinherited
list List<TextValidator>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(String? text) String?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited