Valids class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

length(int minLength, int maxLength, {bool allowEmpty = false, bool trim = false, String? message}) TextValidator
list(List<TextValidator> list) TextValidator
notEmpty({bool trim = true, String message = "不可为空"}) TextValidator
number(num minValue, num maxValue, {bool allowEmpty = false, String? message}) TextValidator
regex(RegExp regex, {MatchType matchType = MatchType.Entire, bool trim = false, bool allowEmpty = false, String message = "格式不符"}) TextValidator