bottoms class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

pickAction(List<XAction> items, {XAction? selected, Widget onItemView(XAction)?, Widget? onTitle(XAction)?, Widget? onSubtitle(XAction)?, Widget? onLeading(XAction)?, Widget? onTrailing(XAction)?, double? itemExtent, bool separator = true, double separatorIndentStart = 0, double separatorIndentEnd = 0, double? minTileVerticalPadding, double? minTileLeadingWidth, double? minTileHeight, bool autoClick = true}) Future<XAction?>
pickGrid<T>(List<T> items, {T? selected, Widget onItemView(T)?, Widget? onTitle(T)?, Widget? onHeader(T)?, Widget? onFooter(T)?, int columnCount = 0, double itemWidth = 80, double? itemHeight, double aspectRatio = 1.0, double verticalSpacing = 0.0, double horizontalSpacing = 0.0, EdgeInsets? padding}) Future<T?>
pickItem<T>(List<T> items, {T? selected, Widget onItemView(T)?, Widget? onTitle(T)?, Widget? onSubtitle(T)?, Widget? onLeading(T)?, Widget? onTrailing(T)?, double? itemExtent, bool separator = true, double separatorIndentStart = 0, double separatorIndentEnd = 0, double? minTileVerticalPadding, double? minTileLeadingWidth, double? minTileHeight}) Future<T?>
pickLabelValue<T>(List<LabelValue<T>> items, {T? selected, Widget onItemView(LabelValue<T>)?, Widget? onTitle(LabelValue<T>)?, Widget? onSubtitle(LabelValue<T>)?, Widget? onLeading(LabelValue<T>)?, Widget? onTrailing(LabelValue<T>)?, double? itemExtent, bool separator = true, double separatorIndentStart = 0, double separatorIndentEnd = 0, double? minTileVerticalPadding, double? minTileLeadingWidth, double? minTileHeight}) Future<LabelValue<T>?>
pickSegment<T>(List<LabelValue<T>> items, {String? message, Set<T>? selected, bool multi = false, bool allowEmpty = true}) Future<Set<T>?>
pickSegmentMulti<T>(List<LabelValue<T>> items, {String? message, Set<T>? selected, bool allowEmpty = true}) Future<Set<T>?>
pickSegmentSingle<T>(List<LabelValue<T>> items, {String? message, T? selected, bool allowEmpty = true}) Future<T?>
show(WidgetBuilder builder, {BuildContext? context, Color? backgroundColor, double? elevation, ShapeBorder? shape, Clip? clipBehavior, BoxConstraints? constraints, bool? enableDrag, bool? showDragHandle, AnimationController? transitionAnimationController, AnimationStyle? sheetAnimationStyle}) PersistentBottomSheetController
showModal<T>(WidgetBuilder builder, {BuildContext? context, Color? backgroundColor, String? barrierLabel, double? elevation, ShapeBorder? shape, Clip? clipBehavior, BoxConstraints? constraints, Color? barrierColor, bool isScrollControlled = false, bool useRootNavigator = false, bool isDismissible = true, bool enableDrag = true, bool? showDragHandle, bool useSafeArea = false, RouteSettings? routeSettings, AnimationController? transitionAnimationController, Offset? anchorPoint, AnimationStyle? sheetAnimationStyle, bool? requestFocus, PropMap? propMap}) Future<T?>
showModalWidget<T>(Widget child, {BuildContext? context, Color? backgroundColor, String? barrierLabel, double? elevation, ShapeBorder? shape, Clip? clipBehavior, BoxConstraints? constraints, Color? barrierColor, bool isScrollControlled = false, bool useRootNavigator = false, bool isDismissible = true, bool enableDrag = true, bool? showDragHandle, bool useSafeArea = false, RouteSettings? routeSettings, AnimationController? transitionAnimationController, Offset? anchorPoint, AnimationStyle? sheetAnimationStyle, bool? requestFocus, PropMap? propMap}) Future<T?>
showModalWith<T>(Widget builder(BuildContext context, PropMap propMap), {required PropMap propMap, BuildContext? context, Color? backgroundColor, String? barrierLabel, double? elevation, ShapeBorder? shape, Clip? clipBehavior, BoxConstraints? constraints, Color? barrierColor, bool isScrollControlled = false, bool useRootNavigator = false, bool isDismissible = true, bool enableDrag = true, bool? showDragHandle, bool useSafeArea = false, RouteSettings? routeSettings, AnimationController? transitionAnimationController, Offset? anchorPoint, AnimationStyle? sheetAnimationStyle, bool? requestFocus}) Future<T?>