DialogBuilderContext<T> class

Constructors

DialogBuilderContext(HareBuilder _rootWidget)

Properties

attrMap ↔ PropMap
getter/setter pair
centerActions bool
getter/setter pair
context BuildContext
getter/setter pair
dialogWidth DialogWidth
getter/setter pair
gridSelectedBackground Color
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
okCallback ↔ BoolFunc?
getter/setter pair
onValidator ↔ RFunc<DataResult<T>>?
getter/setter pair
panelActions Widget?
getter/setter pair
panelTitle Widget?
getter/setter pair
result ↔ T?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spaceActions double
getter/setter pair
textCancel String
getter/setter pair
textOK String
getter/setter pair

Methods

actions({bool? ok, bool? cancel, List<Widget>? items}) → void
build(Widget body, {bool flex = false, String? title, bool? ok, bool? cancel, DialogWidth? dialogWidth}) Widget
buildColumn(List<Widget> children, {String? message, TextAlign? messageAlign, double? messageMinHeight, bool scrollable = false, EdgeInsets? padding = defaultDialogBodyInsets, String? title, bool? ok, bool? cancel, DialogWidth? dialogWidth}) Widget
buildGrid<E>(List<E> items, {required Widget builder(ContextIndexItem<E>), int columnCount = 0, double itemWidth = 80, double? itemHeight, double aspectRatio = 1.0, double verticalSpacing = 0.0, double horizontalSpacing = 0.0, EdgeInsets? padding, String? title, bool? ok, bool? cancel, DialogWidth? dialogWidth, List<Widget>? aboveWidgets, List<Widget>? belowWidgets}) Widget
buildList<E>(List<E> items, {required Widget builder(ContextIndexItem<E>), bool separated = true, EdgeInsets? padding, String? title, bool? ok, bool? cancel, DialogWidth? dialogWidth, List<Widget>? aboveWidgets, List<Widget>? belowWidgets}) Widget
buildScrollable(Widget child, {List<Widget>? aboveWidgets, List<Widget>? belowWidgets, String? title, bool? ok, bool? cancel, DialogWidth? dialogWidth}) Widget
clickCancel() → void
clickOK() → void
init({VoidCallback? block, T? result}) → void
makeAction(String label, VoidCallback onTap) Widget
messageText(String message, {TextAlign? textAlign, double? minHeight}) Widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pop([T? result]) → void
prop<V extends Object>(String name, {V? missValue}) → AnyProp<V>
setResult(T? result) → void
title(Widget? title, {bool closable = true}) → void
titleX({Widget? left, Widget? title, Widget? right, bool closable = true}) → void
toString() String
A string representation of this object.
inherited
updateState() → void

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

ACTION_MIN_WIDTH double
getter/setter pair