DialogWidth class

Properties

hashCode int
The hash code for this object.
no setterinherited
isFill bool
no setter
isFixed bool
no setter
isInstrict bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

middle DialogWidth
getter/setter pair
small DialogWidth
getter/setter pair
W_MIDDLE double
getter/setter pair
W_SMALL double
getter/setter pair

Static Methods

fixed(double w) DialogWidth

Constants

fill → const DialogWidth
instrict → const DialogWidth