StateHolder class
Constructors
Properties
- attrs ↔ PropMap
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- life ↔ HareLife
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state ↔ HareWidgetState?
-
getter/setter pair
Methods
-
get<
T> (String key) → T? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
put(
String key, dynamic value) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited