UpdatableContext class

Constructors

UpdatableContext({required BuildContext context, required HareWidget updatable})

Properties

colorScheme ColorScheme
no setter
context BuildContext
final
hashCode int
The hash code for this object.
no setterinherited
hasResult bool
no setter
onValidate bool Function()
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
themeData ThemeData
no setter

Methods

containsKey(String key) bool
fireAction(String action) → void
get<T>(String key) → T?
getResult<T extends Object>() → T?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onAction(String action, VoidCallback callback) → void
pop<T extends Object>([Object? result]) Future<bool>
popResult<T extends Object>() Future<bool>
set(String key, dynamic value) → void
setResult<T extends Object>(T? value) → void
toString() String
A string representation of this object.
inherited
updateState() → void

Operators

operator ==(Object other) bool
The equality operator.
inherited