AttributeProvider class abstract mixin

Implementers
Available extensions

Constructors

AttributeProvider()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

acceptType<CH>(DType<CH> chtype) bool
acceptValue(Object? value) bool
boolAttribute({required String key, bool missValue = false, AttributeTransform<bool>? transform}) BoolAttribute

Available on AttributeProvider, provided by the AttributeProviderExtend extension

boolOptional({required String key, AttributeTransform<bool>? transform}) BoolOptional

Available on AttributeProvider, provided by the AttributeProviderExtend extension

doubleAttribute({required String key, double missValue = 0, AttributeTransform<double>? transform}) DoubleAttribute

Available on AttributeProvider, provided by the AttributeProviderExtend extension

doubleOptional({required String key, AttributeTransform<double>? transform}) DoubleOptional

Available on AttributeProvider, provided by the AttributeProviderExtend extension

getAttribute(String key) Object?
hasAttribute(String key) bool
intAttribute({required String key, int missValue = 0, AttributeTransform<int>? transform}) IntAttribute

Available on AttributeProvider, provided by the AttributeProviderExtend extension

intOptional({required String key, AttributeTransform<int>? transform}) IntOptional

Available on AttributeProvider, provided by the AttributeProviderExtend extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
optional<T extends Object>({required String key, AttributeTransform<T>? transform}) OptionalAttribute<T>

Available on AttributeProvider, provided by the AttributeProviderExt extension

removeAttribute(String key) Object?
require<T extends Object>({required String key, required T missValue, AttributeTransform<T>? transform}) RequiredAttribute<T>

Available on AttributeProvider, provided by the AttributeProviderExt extension

setAttribute(String key, Object? value) → void
stringAttribute({required String key, String missValue = "", AttributeTransform<String>? transform}) StringAttribute

Available on AttributeProvider, provided by the AttributeProviderExtend extension

stringOptional({required String key, AttributeTransform<String>? transform}) StringOptional

Available on AttributeProvider, provided by the AttributeProviderExtend extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited