JsonModelTransform<T extends JsonModel> class
- Inheritance
-
- Object
- AttributeTransform<
T> - JsonModelTransform
Constructors
- JsonModelTransform({required T creator(JsonValue)})
Properties
-
attributeType
→ DType<
T> -
finalinherited
- creator → T Function(JsonValue)
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
fromRawAttribute(
AttributeProvider provider, Object attr) → T -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toRawAtttribute(
AttributeProvider provider, T value) → Object -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited