JsonValueTransform class

Inheritance

Constructors

JsonValueTransform()

Properties

attributeType DType<JsonValue>
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

fromRawAttribute(AttributeProvider provider, Object attr) → JsonValue
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toRawAtttribute(AttributeProvider provider, JsonValue value) Object
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited