GroupCondition class
- Inheritance
-
- Object
- QueryCondition
- GroupCondition
Constructors
-
GroupCondition(bool isAnd, List<
QueryCondition> conditions) -
GroupCondition.and(List<
QueryCondition> conditions) -
GroupCondition.or(List<
QueryCondition> conditions)
Properties
-
conditions
↔ List<
QueryCondition> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAnd ↔ bool
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
buildCondition(
) → String? -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited