QueryBuilder class

Constructors

QueryBuilder({int offset = 0, int limit = 200, QueryCondition? filter, List<OrderByItem>? sort})

Properties

filter QueryCondition?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
limit int
getter/setter pair
offset int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sort List<OrderByItem>
getter/setter pair

Methods

arguments() List<LabelValue>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
orderBy({required bool asc, required String field}) QueryBuilder
orderByItem(OrderByItem? item) QueryBuilder
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited