SingleCondition class

Inheritance

Constructors

SingleCondition({required QueryOperator op, required String field, required List params})

Properties

field String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
op QueryOperator
getter/setter pair
params List
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildCondition() String?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited