DataColumnY class

Annotations

Constructors

DataColumnY({required Widget label, String? tooltip, bool numeric = false, bool instrict = false, DataColumnSortAction? onSort, WidgetStateProperty<MouseCursor?>? mouseCursor, TableColumnWidth? width, Alignment? alignment})
const

Properties

alignment Alignment?
final
hashCode int
The hash code for this object.
no setterinherited
instrict bool
final
label Widget
final
mouseCursor WidgetStateProperty<MouseCursor?>?
final
numeric bool
final
onSort DataColumnSortAction?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tooltip String?
final
width TableColumnWidth?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited