HareWebsocket class

Constructors

HareWebsocket({WsDelegate? delegate, OnWebSocketText? onText, OnWebSocketBinary? onBinary, OnWebSocketClose? onClose, OnWebSocketError? onError})

Properties

delegate WsDelegate?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isOpen bool
no setter
onBinary OnWebSocketBinary?
getter/setter pair
onClose OnWebSocketClose?
getter/setter pair
onError OnWebSocketError?
getter/setter pair
onText OnWebSocketText?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
websocket ↔ WebSocket?
getter/setter pair

Methods

close() → void
connect(Uri uri) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendBytes(Uint8List data) → void
sendText(String text) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited