WsDelegate class abstract mixin

Implementers

Constructors

WsDelegate()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onWebSocketBinary(Uint8List data) → void
onWebSocketClose(int? code, String reason) → void
onWebSocketError(WebSocketException e) → void
onWebSocketText(String text) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited