AppMap class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- appMap ↔ AnyMap
-
getter/setter pair
Static Methods
-
getDouble(
String key) → double? -
getInt(
String key) → int? -
getString(
String key) → String? -
propAny<
T extends Object> (String key, {T? missValue}) → AnyProp< T> -
propSome<
T extends Object> (String key, {required T missValue}) → SomeProp< T> -
putDouble(
String key, double value) → void -
putInt(
String key, int value) → void -
putString(
String key, String value) → void -
remove(
String key) → void