EntaoApp class
Constructors
- EntaoApp()
Properties
- currentContext → BuildContext
-
no setter
- currentTheme → ThemeData
-
no setter
-
globalKey
↔ GlobalKey<
NavigatorState> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- listTileHorizontalTitleGap ↔ double
-
getter/setter pair
- onLogout ↔ VoidCallback?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textTheme → TextTheme
-
no setter
- themeData → ThemeData
-
no setter
- title ↔ String
-
getter/setter pair
Methods
-
logout(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pop<
T> ([T? result]) → void -
prepare(
) → Future< void> -
run(
Widget? home) → void -
theme(
{ThemeMode? mode, ThemeData? theme, ThemeData? darkTheme, Color? seedColor, Color? darkSeedColor, bool? useMaterial3}) → void -
themeDark(
{bool? useMaterial3}) → void -
themeLight(
{bool? useMaterial3}) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited