ContextIndexItem<T> class
- Inheritance
-
- Object
- ContextIndex
- ContextIndexItem
Constructors
- ContextIndexItem(BuildContext context, int index, T item)
Properties
- context ↔ BuildContext
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- index ↔ int
-
getter/setter pairinherited
- item ↔ T
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
indexBuilder<
V> (List< V> items, Widget itemBuilder(ContextIndexItem<V> )) → IndexedWidgetBuilder -
nullableIndexBuilder<
V> (List< V> items, Widget itemBuilder(ContextIndexItem<V> )) → NullableIndexedWidgetBuilder