LocalJsonModel<T extends JsonModel> class
- Inheritance
-
- Object
- LocalModel<
T> - LocalJsonModel
Constructors
- LocalJsonModel({required String key, required T map(JsonValue)})
Properties
-
decoder
→ LocalDecoder<
T> -
finalinherited
-
encoder
→ LocalEncoder<
T> -
finalinherited
- exists → bool
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value ↔ T?
-
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited