LocalModel<T> class
- Implementers
Constructors
-
LocalModel({required String key, required LocalEncoder<
T> encoder, required LocalDecoder<T> decoder})
Properties
-
decoder
→ LocalDecoder<
T> -
final
-
encoder
→ LocalEncoder<
T> -
final
- exists → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value ↔ T?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited