Binder<T> class
Constructors
-
Binder({required T value, BinderCallback<
T> ? onUpdateUI, BinderCallback<T> ? onChanged})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value ↔ T
-
getter/setter pair
Methods
-
fireChanged(
) → void -
fireUpdateUI(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onChanged(
BinderCallback< T> callback) → void -
onUpdateUI(
BinderCallback< T> callback) → void -
remove(
BinderCallback< T> callback) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited