dialogs class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
alert({required String title, required String message, TextAlign? align})
→ Future<bool?>
-
-
columns<T>(List<Widget> children, {required RFunc<DataResult<T>> validator, String? title, String? message, bool? ok = true, bool? cancel = true, DialogWidth? dialogWidth})
→ Future<T?>
-
-
confirm({required String title, required String message, TextAlign? align})
→ Future<bool?>
-
-
input(HareEdit edit, {required String title, String? message, TextValidator? validator, DialogWidth? dialogWidth})
→ Future<String?>
-
-
input2(HareEdit edit, HareEdit secondEdit, {required String title, String? message, TextValidator? validator, TextValidator? secondValidator, DialogWidth? dialogWidth})
→ Future<({String first, String second})?>
-
-
inputDouble({double? value, required String title, String? label, String? message, double? minValue, double? maxValue})
→ Future<double?>
-
-
inputInt({int? value, required String title, String? label, String? message, int? minValue, int? maxValue})
→ Future<int?>
-
-
inputText({String? value, required String title, String? label, String? message, String? tips, RegExp? allowExp, RegExp? denyExp, TextInputType? keyboardType, List<TextInputFormatter>? inputFormaters, TextValidator? validator, int? maxLines = 1, int minLength = 1, int maxLength = 255, bool allowEmpty = false, bool trim = false, bool? password, DialogWidth? width})
→ Future<String?>
-
-
pickAction(List<XAction> items, {String? title, XAction? selected, Widget onItemView(XAction)?, Widget? onTitle(XAction)?, Widget? onSubtitle(XAction)?, Widget? onLeading(XAction)?, Widget? onTrailing(XAction)?, List<Widget>? aboveWidgets, List<Widget>? belowWidgets, DialogWidth? width, bool withOKCancel = false})
→ Future<XAction?>
-
-
pickGridValue<T>(List<T> items, {T? selected, Widget onItemView(T)?, Widget? onTitle(T)?, int columnCount = 0, double itemWidth = 80, double? itemHeight, double aspectRatio = 1.0, double verticalSpacing = 0.0, double horizontalSpacing = 0.0, EdgeInsets? padding, String? title, bool ok = false, bool cancel = false, DialogWidth? dialogWidth, List<Widget>? aboveWidgets, List<Widget>? belowWidgets, Alignment? dialogAlignment, EdgeInsets? dialogInsets})
→ Future<T?>
-
-
pickGridValueSet<T>(List<T> items, {Iterable<T>? selected, String? title, Widget onItemView(T, Set<T>)?, Widget? onTitle(T)?, List<Widget>? aboveWidgets, List<Widget>? belowWidgets, int columnCount = 0, double itemWidth = 80, double? itemHeight, double aspectRatio = 1.0, double verticalSpacing = 0.0, double horizontalSpacing = 0.0, EdgeInsets? padding, DialogWidth? dialogWidth})
→ Future<Set<T>?>
-
-
pickLabelValue<T>(List<LabelValue<T>> items, {T? selected, String? title, Widget onItemView(LabelValue<T>)?, Widget? onTitle(LabelValue<T>)?, Widget? onSubtitle(LabelValue<T>)?, Widget? onLeading(LabelValue<T>)?, Widget? onTrailing(LabelValue<T>)?, List<Widget>? aboveWidgets, List<Widget>? belowWidgets, DialogWidth? width, bool withOKCancel = false})
→ Future<LabelValue<T>?>
-
-
pickLabelValueSet<T>(List<LabelValue<T>> items, {Iterable<T>? selected, String? title, Widget onItemView(LabelValue<T>)?, Widget? onTitle(LabelValue<T>)?, Widget? onSubtitle(LabelValue<T>)?, Widget? onLeading(LabelValue<T>)?, Widget? onTrailing(LabelValue<T>)?, List<Widget>? aboveWidgets, List<Widget>? belowWidgets, DialogWidth? width})
→ Future<Set<LabelValue<T>>?>
-
-
pickSegmentMulti<T>(List<LabelValue<T>> items, {String? title, String? message, Set<T>? selected, bool allowEmpty = false})
→ Future<Set<T>?>
-
-
pickSegmentSingle<T>(List<LabelValue<T>> items, {String? title, String? message, T? selected, bool allowEmpty = false})
→ Future<T?>
-
-
pickSegmentValue<T>(List<LabelValue<T>> items, {String? title, String? message, Set<T>? selected, bool multi = false, bool allowEmpty = false})
→ Future<Set<T>?>
-
-
pickValue<T>(List<T> items, {T? selected, String? title, Widget onItemView(T)?, Widget? onTitle(T)?, Widget? onSubtitle(T)?, Widget? onLeading(T)?, Widget? onTrailing(T)?, List<Widget>? aboveWidgets, List<Widget>? belowWidgets, DialogWidth? width, bool withOKCancel = false})
→ Future<T?>
-
-
pickValueSet<T>(List<T> items, {Iterable<T>? selected, String? title, Widget onItemView(T, Set<T>)?, Widget? onTitle(T)?, Widget? onSubtitle(T)?, Widget? onLeading(T)?, Widget? onTrailing(T)?, List<Widget>? aboveWidgets, List<Widget>? belowWidgets, DialogWidth? dialogWidth})
→ Future<Set<T>?>
-
-
pop<T>([T? result])
→ void
-
-
showChips<T>({required List<LabelValue<T>> items, Set<T>? selected, Widget? title, bool allowEmpty = true, bool multiSelect = false, Widget? above, Widget? below})
→ Future<Set<T>?>
-
-
showPage<T>(HarePage page, {bool flex = true, bool closable = false, DialogWidth? dialogWidth})
→ Future<T?>
-