DialogOptions class
Constructors
Properties
- alignment ↔ AlignmentGeometry?
-
getter/setter pair
- backgroundColor ↔ Color?
-
getter/setter pair
- child ↔ Widget?
-
getter/setter pair
- clipBehavior ↔ Clip?
-
getter/setter pair
- constraints ↔ BoxConstraints?
-
getter/setter pair
- elevation ↔ double?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- insetAnimationCurve ↔ Curve
-
getter/setter pair
- insetAnimationDuration ↔ Duration
-
getter/setter pair
- insetPadding ↔ EdgeInsets?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shadowColor ↔ Color?
-
getter/setter pair
- shape ↔ ShapeBorder?
-
getter/setter pair
- surfaceTintColor ↔ Color?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited