RequiredValue<T extends Object> mixin
- Superclass constraints
- Mixin applications
Properties
-
attributeType
→ DType<
T> -
finalinherited
- exists → bool
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String
-
finalinherited
- missValue → T
-
no setter
- provider → AttributeProvider
-
finalinherited
- rawValue ↔ Object?
-
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
transform
→ AttributeTransform<
T> ? -
finalinherited
- value ↔ T
-
getter/setter pairinherited-setteroverride-getter
Methods
-
fromRawAttribute(
Object attr) → T -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toRawAtttribute(
T value) → Object -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited