ConditionListMix mixin
- Mixin applications
Properties
- buildQueryString → String?
-
no setter
-
conditionList
↔ List<
QueryWidget> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addConditions(
List< QueryWidget> ws) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onQueryConditionChanged(
String? q) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited