QueryOperator enum
Values
- eq → const QueryOperator
-
const QueryOperator(op: "eq", label: "=") - ne → const QueryOperator
-
const QueryOperator(op: "ne", label: "≠") - ge → const QueryOperator
-
const QueryOperator(op: "ge", label: "≥") - le → const QueryOperator
-
const QueryOperator(op: "le", label: "≤") - gt → const QueryOperator
-
const QueryOperator(op: "gt", label: ">") - lt → const QueryOperator
-
const QueryOperator(op: "lt", label: "<") - bit → const QueryOperator
-
const QueryOperator(op: "bit", label: "拥有标识") - inset → const QueryOperator
-
const QueryOperator(op: "in", label: "集合") - nul → const QueryOperator
-
const QueryOperator(op: "nul", label: "是空") - start → const QueryOperator
-
const QueryOperator(op: "start", label: "开始于") - end → const QueryOperator
-
const QueryOperator(op: "end", label: "结束于") - contain → const QueryOperator
-
const QueryOperator(op: "contain", label: "包含")
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- label → String
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - op → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
String field, List valueList) → String? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
QueryOperator> - A constant List of the values in this enum, in order of their declaration.